@@ -4,8 +4,9 @@
 #include <QMainWindow>
 #include <QModelIndex>
 
-namespace Ui {
-    class MainWindow;
+namespace Ui
+{
+class MainWindow;
 }
 class RCQTextEdit;
 class MainWindow : public QMainWindow
@@ -21,7 +22,7 @@ public:
 private:
     Ui::MainWindow *ui;
 protected:
-     void closeEvent(QCloseEvent *event);
+    void closeEvent(QCloseEvent *event);
 
 private slots:
     void save_ini();
@@ -80,6 +81,9 @@ private slots:
     bool checkmodule(QString nmodule);
     int cuttercount(QString row);
     int cutterint(QString row, int place);
+    QString getBTproperty(QString key);
+    QString getBTname();
+    QString getBTdevPath();
     QString getlsof();
     QString write_filter(QString);
     QString filterlog(QString linelog);
@@ -121,6 +125,10 @@ private slots:
     void on_pushButton_wstartstop_clicked();
     void on_pushButton_wadhoc_clicked();
     void on_pushButton_sshstartstop_clicked();
+    void on_pushButton_btsave_clicked();
+    void on_pushButton_btonoff_clicked();
+    void on_pushButton_btstartstop_clicked();
+    void on_pushButton_delboot_clicked();
 };
 
 #endif // MAINWINDOW_H
